@@ -81,6 +81,7 @@ class TaskScheduler:
     _tasks: Dict[str, Task]
     _scheduler: AsyncIOScheduler
     produce_method: ProduceCall
+    state: Dict[str, Any]
 
     def __init__(self, executors: Dict[str, BaseExecutor] = None, job_defaults=None,
                  **kwargs):
@@ -93,10 +94,6 @@ class TaskScheduler:
             'coalesce': False,
             'max_instances': 10
         }
-        # self._scheduler = BackgroundScheduler(jobstores={"default": MemoryJobStore()},
-        #                                       executors=executors if executors else executor,
-        #                                       job_defaults=job_defaults if job_defaults else job_default,
-        #                                       timezone=utc)
         self._scheduler = AsyncIOScheduler(jobstores={"default": MemoryJobStore()},
                                            executors=executors if executors else executor,
                                            job_defaults=job_defaults if job_defaults else job_default,
