@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TypeVar
 
-from pydantic import BaseSettings
+from pydantic import BaseSettings, BaseModel
 
 from web_foundation.config import GenericConfig
 from web_foundation.kernel.messaging.channel import IChannel
@@ -15,7 +15,7 @@ from web_foundation.utils.helpers import in_obj_subclasses, in_obj_classes
 
 
 class DependencyContainer:
-    app_config: Dependency[GenericConfig] = Dependency(instance_of=BaseSettings)
+    app_config: Dependency[GenericConfig] = Dependency(instance_of=BaseModel)
     data_store: Dependency[DataStore] = Dependency(instance_of=DataStore)
     file_repository: Dependency[FilesResource] = Dependency(instance_of=FilesResource)
 
