@@ -5,7 +5,6 @@ from multiprocessing import Queue
 from typing import Coroutine, Callable, Dict, Type, List, Any
 from typing import TypeVar
 
-from aioprocessing import AioQueue
 from loguru import logger
 
 from web_foundation import settings
@@ -45,7 +44,7 @@ class IMessageWaiter:
 class IChannel:
     read_timeout = 0.01
     worker_name: str
-    consume_pipe: AioQueue
+    consume_pipe: Queue
     produce_pipe: Queue
 
     _listeners: Dict[str, List[EventListener]]
@@ -132,7 +131,7 @@ class IChannel:
         task = IMessageWaiter()
         await self.produce(msg)
         self._response_waiters.update({msg.inner_index: task})
-        while not task.result:
+        while task.result is None:
             await asyncio.sleep(0.01)
         self._response_waiters.pop(msg.inner_index)
         return task.result
