@@ -4,8 +4,8 @@ from typing import Callable, Awaitable, Any
 from typing import List, TypeVar, Tuple, Generic
 
 from pydantic import BaseModel as PdModel
-from tortoise import Tortoise, connections
 from tortoise.exceptions import IntegrityError, FieldError
+from tortoise.expressions import RawSQL
 from tortoise.queryset import QuerySet, MODEL
 
 from web_foundation.errors.app.application import InconsistencyError
@@ -119,13 +119,9 @@ class ModelLoader(Generic[GenericDbType]):
             entities = await query
             query._limit = None
             query._offset = None
-            query = query.count()
-            # --- todo something more flexible --- #
-            conn = [conn.connection_name for conn in connections.all() if "default" in conn.connection_name][0]
-            con = Tortoise.get_connection(conn)
-            query = str(query.sql()).replace('COUNT(*)',
-                                             f'COUNT(DISTINCT "{model._meta.db_table}"."id")')  # what if model haven't id?
-            _, res = await con.execute_query(query)
+            query._orderings = []
+            query = query.annotate(count=RawSQL(f'COUNT(DISTINCT "{model._meta.db_table}"."id")')).values('count')  # what if model haven't id?
+            res = await query
             total = res[0].get('count')
             # ------------------------------------ #
         except FieldError:
