@@ -1,8 +1,7 @@
 from abc import ABCMeta
-from enum import Enum
-from typing import Any, Dict, TypeVar, Generic, Type
+from typing import Any
 
-from web_foundation.kernel.resource import Resource
+from web_foundation.resources.resource import Resource
 
 
 class FilesResource(Resource, metaclass=ABCMeta):
